@@ -1,6 +1,6 @@
 import os
 
-from github import Github, Repository, PullRequest
+from ruamel.yaml import YAML
 
 
 class GitContext(dict):
@@ -15,23 +15,10 @@ def fetch_token(host, options, context):
 
     gh_hosts = os.path.expanduser('~/.config/gh/hosts.yml')
     if os.path.exists(gh_hosts):
+        yaml = YAML()
         with open(gh_hosts, 'r') as f:
-            gh_hosts = yaml.load(f, Loader=yaml.FullLoader)
+            gh_hosts = yaml.load(f)
         if host in gh_hosts:
             return gh_hosts[host]['oauth_token']
     
     return context.environ.get('GITHUB_TOKEN')
-
-
-# def create_repo():
-#     token = fetch_token(host, options, context)
-#     g = Github(token)
-#     org = g.get_organization(name)
-
-
-# def clone_new_branch():
-#     pass
-
-
-# def new_pr():
-#     pass
